Class: Google::Cloud::Channel::V1::AssociationInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/channel/v1/entitlements.rb

Overview

Association links that an entitlement has to other entitlements.

Instance Attribute Summary collapse

Instance Attribute Details

#base_entitlement::String

Returns The name of the base entitlement, for which this entitlement is an add-on.

Returns:

  • (::String)

    The name of the base entitlement, for which this entitlement is an add-on.



159
160
161
162
# File 'proto_docs/google/cloud/channel/v1/entitlements.rb', line 159

class AssociationInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end