Class: Google::Cloud::Channel::V1::CloudIdentityCustomerAccount

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/channel/v1/service.rb

Overview

Entity representing a Cloud Identity account that may be associated with a Channel Services API partner.

Instance Attribute Summary collapse

Instance Attribute Details

#channel_partner_cloud_identity_id::String

Returns If existing = true, and is 2-tier customer, the channel partner of the customer.

Returns:

  • (::String)

    If existing = true, and is 2-tier customer, the channel partner of the customer.



70
71
72
73
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 70

class CloudIdentityCustomerAccount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#customer_cloud_identity_id::String

Returns If existing = true, the Cloud Identity ID of the customer.

Returns:

  • (::String)

    If existing = true, the Cloud Identity ID of the customer.



70
71
72
73
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 70

class CloudIdentityCustomerAccount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#customer_name::String

Returns If owned = true, the name of the customer that owns the Cloud Identity account. Customer_name uses the format: accounts/{account_id}/customers/{customer_id}.

Returns:

  • (::String)

    If owned = true, the name of the customer that owns the Cloud Identity account. Customer_name uses the format: accounts/{account_id}/customers/{customer_id}



70
71
72
73
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 70

class CloudIdentityCustomerAccount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#customer_type::Google::Cloud::Channel::V1::CloudIdentityInfo::CustomerType

Returns If existing = true, the type of the customer.

Returns:



70
71
72
73
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 70

class CloudIdentityCustomerAccount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#existing::Boolean

Returns true if a Cloud Identity account exists for a specific domain.

Returns:

  • (::Boolean)

    Returns true if a Cloud Identity account exists for a specific domain.



70
71
72
73
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 70

class CloudIdentityCustomerAccount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#owned::Boolean

Returns true if the Cloud Identity account is associated with a customer of the Channel Services partner (with active subscriptions or purchase consents).

Returns:

  • (::Boolean)

    Returns true if the Cloud Identity account is associated with a customer of the Channel Services partner (with active subscriptions or purchase consents).



70
71
72
73
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 70

class CloudIdentityCustomerAccount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end