Class: Google::Cloud::Channel::V1::ListCustomersRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/channel/v1/service.rb

Overview

Request message for CloudChannelService.ListCustomers

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filters applied to the [CloudChannelService.ListCustomers] results. See https://cloud.google.com/channel/docs/concepts/google-cloud/filter-customers for more information.

Returns:



110
111
112
113
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 110

class ListCustomersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of customers to return. The service may return fewer than this value. If unspecified, returns at most 10 customers. The maximum value is 50.

Returns:

  • (::Integer)

    Optional. The maximum number of customers to return. The service may return fewer than this value. If unspecified, returns at most 10 customers. The maximum value is 50.



110
111
112
113
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 110

class ListCustomersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results other than the first page. Obtained through ListCustomersResponse.next_page_token of the previous CloudChannelService.ListCustomers call.

Returns:



110
111
112
113
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 110

class ListCustomersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the reseller account to list customers from. Parent uses the format: accounts/{account_id}.

Returns:

  • (::String)

    Required. The resource name of the reseller account to list customers from. Parent uses the format: accounts/{account_id}.



110
111
112
113
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 110

class ListCustomersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end