Class: Google::Cloud::Channel::V1::ListPurchasableOffersRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Channel::V1::ListPurchasableOffersRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/channel/v1/service.rb
Overview
Request message for ListPurchasableOffers.
Defined Under Namespace
Classes: ChangeOfferPurchase, CreateEntitlementPurchase
Instance Attribute Summary collapse
-
#change_offer_purchase ⇒ ::Google::Cloud::Channel::V1::ListPurchasableOffersRequest::ChangeOfferPurchase
List Offers for ChangeOffer purchase.
-
#create_entitlement_purchase ⇒ ::Google::Cloud::Channel::V1::ListPurchasableOffersRequest::CreateEntitlementPurchase
List Offers for CreateEntitlement purchase.
-
#customer ⇒ ::String
Required.
-
#language_code ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
Instance Attribute Details
#change_offer_purchase ⇒ ::Google::Cloud::Channel::V1::ListPurchasableOffersRequest::ChangeOfferPurchase
Returns List Offers for ChangeOffer purchase.
Note: The following fields are mutually exclusive: change_offer_purchase, create_entitlement_purchase. If a field in that set is populated, all other fields in the set will automatically be cleared.
1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1449 class ListPurchasableOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List Offers for CreateEntitlement purchase. # @!attribute [rw] sku # @return [::String] # Required. SKU that the result should be restricted to. # Format: products/\\{product_id}/skus/\\{sku_id}. # @!attribute [rw] billing_account # @return [::String] # Optional. Billing account that the result should be restricted to. # Format: accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List Offers for ChangeOffer purchase. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] new_sku # @return [::String] # Optional. Resource name of the new target SKU. Provide this SKU when # upgrading or downgrading an entitlement. Format: # products/\\{product_id}/skus/\\{sku_id} # @!attribute [rw] billing_account # @return [::String] # Optional. Resource name of the new target Billing Account. Provide this # Billing Account when setting up billing for a trial subscription. Format: # accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. # # This field is only relevant for multi-currency accounts. It should be # left empty for single currency accounts. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_entitlement_purchase ⇒ ::Google::Cloud::Channel::V1::ListPurchasableOffersRequest::CreateEntitlementPurchase
Returns List Offers for CreateEntitlement purchase.
Note: The following fields are mutually exclusive: create_entitlement_purchase, change_offer_purchase. If a field in that set is populated, all other fields in the set will automatically be cleared.
1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1449 class ListPurchasableOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List Offers for CreateEntitlement purchase. # @!attribute [rw] sku # @return [::String] # Required. SKU that the result should be restricted to. # Format: products/\\{product_id}/skus/\\{sku_id}. # @!attribute [rw] billing_account # @return [::String] # Optional. Billing account that the result should be restricted to. # Format: accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List Offers for ChangeOffer purchase. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] new_sku # @return [::String] # Optional. Resource name of the new target SKU. Provide this SKU when # upgrading or downgrading an entitlement. Format: # products/\\{product_id}/skus/\\{sku_id} # @!attribute [rw] billing_account # @return [::String] # Optional. Resource name of the new target Billing Account. Provide this # Billing Account when setting up billing for a trial subscription. Format: # accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. # # This field is only relevant for multi-currency accounts. It should be # left empty for single currency accounts. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#customer ⇒ ::String
Returns Required. The resource name of the customer to list Offers for. Format: accounts/{account_id}/customers/{customer_id}.
1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1449 class ListPurchasableOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List Offers for CreateEntitlement purchase. # @!attribute [rw] sku # @return [::String] # Required. SKU that the result should be restricted to. # Format: products/\\{product_id}/skus/\\{sku_id}. # @!attribute [rw] billing_account # @return [::String] # Optional. Billing account that the result should be restricted to. # Format: accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List Offers for ChangeOffer purchase. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] new_sku # @return [::String] # Optional. Resource name of the new target SKU. Provide this SKU when # upgrading or downgrading an entitlement. Format: # products/\\{product_id}/skus/\\{sku_id} # @!attribute [rw] billing_account # @return [::String] # Optional. Resource name of the new target Billing Account. Provide this # Billing Account when setting up billing for a trial subscription. Format: # accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. # # This field is only relevant for multi-currency accounts. It should be # left empty for single currency accounts. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#language_code ⇒ ::String
Returns Optional. The BCP-47 language code. For example, "en-US". The response will localize in the corresponding language code, if specified. The default value is "en-US".
1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1449 class ListPurchasableOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List Offers for CreateEntitlement purchase. # @!attribute [rw] sku # @return [::String] # Required. SKU that the result should be restricted to. # Format: products/\\{product_id}/skus/\\{sku_id}. # @!attribute [rw] billing_account # @return [::String] # Optional. Billing account that the result should be restricted to. # Format: accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List Offers for ChangeOffer purchase. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] new_sku # @return [::String] # Optional. Resource name of the new target SKU. Provide this SKU when # upgrading or downgrading an entitlement. Format: # products/\\{product_id}/skus/\\{sku_id} # @!attribute [rw] billing_account # @return [::String] # Optional. Resource name of the new target Billing Account. Provide this # Billing Account when setting up billing for a trial subscription. Format: # accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. # # This field is only relevant for multi-currency accounts. It should be # left empty for single currency accounts. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server might return fewer results than requested. If unspecified, returns at most 100 Offers. The maximum value is 1000; the server will coerce values above 1000.
1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1449 class ListPurchasableOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List Offers for CreateEntitlement purchase. # @!attribute [rw] sku # @return [::String] # Required. SKU that the result should be restricted to. # Format: products/\\{product_id}/skus/\\{sku_id}. # @!attribute [rw] billing_account # @return [::String] # Optional. Billing account that the result should be restricted to. # Format: accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List Offers for ChangeOffer purchase. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] new_sku # @return [::String] # Optional. Resource name of the new target SKU. Provide this SKU when # upgrading or downgrading an entitlement. Format: # products/\\{product_id}/skus/\\{sku_id} # @!attribute [rw] billing_account # @return [::String] # Optional. Resource name of the new target Billing Account. Provide this # Billing Account when setting up billing for a trial subscription. Format: # accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. # # This field is only relevant for multi-currency accounts. It should be # left empty for single currency accounts. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#page_token ⇒ ::String
Returns Optional. A token for a page of results other than the first page.
1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1449 class ListPurchasableOffersRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List Offers for CreateEntitlement purchase. # @!attribute [rw] sku # @return [::String] # Required. SKU that the result should be restricted to. # Format: products/\\{product_id}/skus/\\{sku_id}. # @!attribute [rw] billing_account # @return [::String] # Optional. Billing account that the result should be restricted to. # Format: accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List Offers for ChangeOffer purchase. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] new_sku # @return [::String] # Optional. Resource name of the new target SKU. Provide this SKU when # upgrading or downgrading an entitlement. Format: # products/\\{product_id}/skus/\\{sku_id} # @!attribute [rw] billing_account # @return [::String] # Optional. Resource name of the new target Billing Account. Provide this # Billing Account when setting up billing for a trial subscription. Format: # accounts/\\{account_id}/billingAccounts/\\{billing_account_id}. # # This field is only relevant for multi-currency accounts. It should be # left empty for single currency accounts. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |