Class: Google::Cloud::Channel::V1::ListPurchasableSkusRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Channel::V1::ListPurchasableSkusRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/channel/v1/service.rb
Overview
Request message for ListPurchasableSkus.
Defined Under Namespace
Classes: ChangeOfferPurchase, CreateEntitlementPurchase
Instance Attribute Summary collapse
-
#change_offer_purchase ⇒ ::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::ChangeOfferPurchase
List SKUs for ChangeOffer purchase with a new SKU.
-
#create_entitlement_purchase ⇒ ::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::CreateEntitlementPurchase
List SKUs for CreateEntitlement purchase.
-
#customer ⇒ ::String
Required.
-
#language_code ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
Instance Attribute Details
#change_offer_purchase ⇒ ::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::ChangeOfferPurchase
Returns List SKUs for ChangeOffer purchase with a new SKU.
Note: The following fields are mutually exclusive: change_offer_purchase, create_entitlement_purchase. If a field in that set is populated, all other fields in the set will automatically be cleared.
1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1354 class ListPurchasableSkusRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List SKUs for a new entitlement. Make the purchase using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#create_entitlement CloudChannelService.CreateEntitlement}. # @!attribute [rw] product # @return [::String] # Required. List SKUs belonging to this Product. # Format: products/\\{product_id}. # Supports products/- to retrieve SKUs for all products. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List SKUs for upgrading or downgrading an entitlement. Make the purchase # using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#change_offer CloudChannelService.ChangeOffer}. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] change_type # @return [::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::ChangeOfferPurchase::ChangeType] # Required. Change Type for the entitlement. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Change Type enum. module ChangeType # Not used. CHANGE_TYPE_UNSPECIFIED = 0 # SKU is an upgrade on the current entitlement. UPGRADE = 1 # SKU is a downgrade on the current entitlement. DOWNGRADE = 2 end end end |
#create_entitlement_purchase ⇒ ::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::CreateEntitlementPurchase
Returns List SKUs for CreateEntitlement purchase.
Note: The following fields are mutually exclusive: create_entitlement_purchase, change_offer_purchase. If a field in that set is populated, all other fields in the set will automatically be cleared.
1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1354 class ListPurchasableSkusRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List SKUs for a new entitlement. Make the purchase using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#create_entitlement CloudChannelService.CreateEntitlement}. # @!attribute [rw] product # @return [::String] # Required. List SKUs belonging to this Product. # Format: products/\\{product_id}. # Supports products/- to retrieve SKUs for all products. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List SKUs for upgrading or downgrading an entitlement. Make the purchase # using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#change_offer CloudChannelService.ChangeOffer}. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] change_type # @return [::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::ChangeOfferPurchase::ChangeType] # Required. Change Type for the entitlement. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Change Type enum. module ChangeType # Not used. CHANGE_TYPE_UNSPECIFIED = 0 # SKU is an upgrade on the current entitlement. UPGRADE = 1 # SKU is a downgrade on the current entitlement. DOWNGRADE = 2 end end end |
#customer ⇒ ::String
Returns Required. The resource name of the customer to list SKUs for. Format: accounts/{account_id}/customers/{customer_id}.
1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1354 class ListPurchasableSkusRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List SKUs for a new entitlement. Make the purchase using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#create_entitlement CloudChannelService.CreateEntitlement}. # @!attribute [rw] product # @return [::String] # Required. List SKUs belonging to this Product. # Format: products/\\{product_id}. # Supports products/- to retrieve SKUs for all products. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List SKUs for upgrading or downgrading an entitlement. Make the purchase # using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#change_offer CloudChannelService.ChangeOffer}. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] change_type # @return [::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::ChangeOfferPurchase::ChangeType] # Required. Change Type for the entitlement. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Change Type enum. module ChangeType # Not used. CHANGE_TYPE_UNSPECIFIED = 0 # SKU is an upgrade on the current entitlement. UPGRADE = 1 # SKU is a downgrade on the current entitlement. DOWNGRADE = 2 end end end |
#language_code ⇒ ::String
Returns Optional. The BCP-47 language code. For example, "en-US". The response will localize in the corresponding language code, if specified. The default value is "en-US".
1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1354 class ListPurchasableSkusRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List SKUs for a new entitlement. Make the purchase using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#create_entitlement CloudChannelService.CreateEntitlement}. # @!attribute [rw] product # @return [::String] # Required. List SKUs belonging to this Product. # Format: products/\\{product_id}. # Supports products/- to retrieve SKUs for all products. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List SKUs for upgrading or downgrading an entitlement. Make the purchase # using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#change_offer CloudChannelService.ChangeOffer}. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] change_type # @return [::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::ChangeOfferPurchase::ChangeType] # Required. Change Type for the entitlement. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Change Type enum. module ChangeType # Not used. CHANGE_TYPE_UNSPECIFIED = 0 # SKU is an upgrade on the current entitlement. UPGRADE = 1 # SKU is a downgrade on the current entitlement. DOWNGRADE = 2 end end end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server might return fewer results than requested. If unspecified, returns at most 100 SKUs. The maximum value is 1000; the server will coerce values above 1000.
1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1354 class ListPurchasableSkusRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List SKUs for a new entitlement. Make the purchase using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#create_entitlement CloudChannelService.CreateEntitlement}. # @!attribute [rw] product # @return [::String] # Required. List SKUs belonging to this Product. # Format: products/\\{product_id}. # Supports products/- to retrieve SKUs for all products. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List SKUs for upgrading or downgrading an entitlement. Make the purchase # using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#change_offer CloudChannelService.ChangeOffer}. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] change_type # @return [::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::ChangeOfferPurchase::ChangeType] # Required. Change Type for the entitlement. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Change Type enum. module ChangeType # Not used. CHANGE_TYPE_UNSPECIFIED = 0 # SKU is an upgrade on the current entitlement. UPGRADE = 1 # SKU is a downgrade on the current entitlement. DOWNGRADE = 2 end end end |
#page_token ⇒ ::String
Returns Optional. A token for a page of results other than the first page.
1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 |
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1354 class ListPurchasableSkusRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List SKUs for a new entitlement. Make the purchase using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#create_entitlement CloudChannelService.CreateEntitlement}. # @!attribute [rw] product # @return [::String] # Required. List SKUs belonging to this Product. # Format: products/\\{product_id}. # Supports products/- to retrieve SKUs for all products. class CreateEntitlementPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # List SKUs for upgrading or downgrading an entitlement. Make the purchase # using # {::Google::Cloud::Channel::V1::CloudChannelService::Client#change_offer CloudChannelService.ChangeOffer}. # @!attribute [rw] entitlement # @return [::String] # Required. Resource name of the entitlement. # Format: # accounts/\\{account_id}/customers/\\{customer_id}/entitlements/\\{entitlement_id} # @!attribute [rw] change_type # @return [::Google::Cloud::Channel::V1::ListPurchasableSkusRequest::ChangeOfferPurchase::ChangeType] # Required. Change Type for the entitlement. class ChangeOfferPurchase include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Change Type enum. module ChangeType # Not used. CHANGE_TYPE_UNSPECIFIED = 0 # SKU is an upgrade on the current entitlement. UPGRADE = 1 # SKU is a downgrade on the current entitlement. DOWNGRADE = 2 end end end |