Class: Google::Cloud::Channel::V1::ListSubscribersRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/channel/v1/service.rb

Overview

Request Message for ListSubscribers.

Instance Attribute Summary collapse

Instance Attribute Details

#account::String

Returns Optional. Resource name of the account. Required if integrator is not provided. Otherwise, leave this field empty/unset.

Returns:

  • (::String)

    Optional. Resource name of the account. Required if integrator is not provided. Otherwise, leave this field empty/unset.



1644
1645
1646
1647
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1644

class ListSubscribersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#integrator::String

Returns Optional. Resource name of the integrator. Required if account is not provided. Otherwise, leave this field empty/unset.

Returns:

  • (::String)

    Optional. Resource name of the integrator. Required if account is not provided. Otherwise, leave this field empty/unset.



1644
1645
1646
1647
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1644

class ListSubscribersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of service accounts to return. The service may return fewer than this value. If unspecified, returns at most 100 service accounts. The maximum value is 1000; the server will coerce values above 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of service accounts to return. The service may return fewer than this value. If unspecified, returns at most 100 service accounts. The maximum value is 1000; the server will coerce values above 1000.



1644
1645
1646
1647
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1644

class ListSubscribersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListSubscribers call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListSubscribers must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListSubscribers call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListSubscribers must match the call that provided the page token.



1644
1645
1646
1647
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1644

class ListSubscribersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end