Class: Google::Cloud::Channel::V1::Price
- Inherits:
-
Object
- Object
- Google::Cloud::Channel::V1::Price
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/channel/v1/offers.rb
Overview
Represents the price of the Offer.
Instance Attribute Summary collapse
-
#base_price ⇒ ::Google::Type::Money
Base price.
-
#discount ⇒ ::Float
Discount percentage, represented as decimal.
-
#discount_components ⇒ ::Array<::Google::Cloud::Channel::V1::DiscountComponent>
Breakdown of the discount into its components.
-
#effective_price ⇒ ::Google::Type::Money
Effective Price after applying the discounts.
-
#external_price_uri ⇒ ::String
Link to external price list, such as link to Google Voice rate card.
-
#price_period ⇒ ::Google::Cloud::Channel::V1::Period
The time period with respect to which base and effective prices are defined.
Instance Attribute Details
#base_price ⇒ ::Google::Type::Money
Returns Base price.
203 204 205 206 |
# File 'proto_docs/google/cloud/channel/v1/offers.rb', line 203 class Price include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#discount ⇒ ::Float
Returns Discount percentage, represented as decimal. For example, a 20% discount will be represent as 0.2.
203 204 205 206 |
# File 'proto_docs/google/cloud/channel/v1/offers.rb', line 203 class Price include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#discount_components ⇒ ::Array<::Google::Cloud::Channel::V1::DiscountComponent>
Returns Breakdown of the discount into its components. This will be empty if there is no discount present.
203 204 205 206 |
# File 'proto_docs/google/cloud/channel/v1/offers.rb', line 203 class Price include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#effective_price ⇒ ::Google::Type::Money
Returns Effective Price after applying the discounts.
203 204 205 206 |
# File 'proto_docs/google/cloud/channel/v1/offers.rb', line 203 class Price include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#external_price_uri ⇒ ::String
Returns Link to external price list, such as link to Google Voice rate card.
203 204 205 206 |
# File 'proto_docs/google/cloud/channel/v1/offers.rb', line 203 class Price include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#price_period ⇒ ::Google::Cloud::Channel::V1::Period
Returns The time period with respect to which base and effective prices are defined. Example: 1 month, 6 months, 1 year, etc.
203 204 205 206 |
# File 'proto_docs/google/cloud/channel/v1/offers.rb', line 203 class Price include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |