Class: Google::Cloud::Channel::V1::PurchasableOffer

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/channel/v1/service.rb

Overview

Offer that you can purchase for a customer. This is used in the ListPurchasableOffer API response.

Instance Attribute Summary collapse

Instance Attribute Details

#offer::Google::Cloud::Channel::V1::Offer

Returns Offer.

Returns:



1514
1515
1516
1517
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1514

class PurchasableOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#price_reference_id::String

Returns Optional. Price reference ID for the offer. Only for offers that require additional price information. Used to guarantee that the pricing is consistent between quoting the offer and placing the order.

Returns:

  • (::String)

    Optional. Price reference ID for the offer. Only for offers that require additional price information. Used to guarantee that the pricing is consistent between quoting the offer and placing the order.



1514
1515
1516
1517
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 1514

class PurchasableOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end