Class: Google::Cloud::Channel::V1::TransferableOffer

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/channel/v1/service.rb

Overview

TransferableOffer represents an Offer that can be used in Transfer. Read-only.

Instance Attribute Summary collapse

Instance Attribute Details

#offer::Google::Cloud::Channel::V1::Offer

Returns Offer with parameter constraints updated to allow the Transfer.

Returns:



432
433
434
435
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 432

class TransferableOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#price_reference_id::String

Returns Optional. Price reference ID for the offer. Only for offers that require additional price information. Used to guarantee that the pricing is consistent between quoting the offer and placing the order.

Returns:

  • (::String)

    Optional. Price reference ID for the offer. Only for offers that require additional price information. Used to guarantee that the pricing is consistent between quoting the offer and placing the order.



432
433
434
435
# File 'proto_docs/google/cloud/channel/v1/service.rb', line 432

class TransferableOffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end