Class: Google::Cloud::Channel::V1::DiscountComponent
- Inherits:
-
Object
- Object
- Google::Cloud::Channel::V1::DiscountComponent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/channel/v1/offers.rb
Overview
Represents a single component of the total discount applicable on a Price.
Instance Attribute Summary collapse
-
#discount_absolute ⇒ ::Google::Type::Money
Fixed value discount.
-
#discount_percentage ⇒ ::Float
Discount percentage, represented as decimal.
-
#discount_type ⇒ ::Google::Cloud::Channel::V1::DiscountType
Type of the discount.
Instance Attribute Details
#discount_absolute ⇒ ::Google::Type::Money
Returns Fixed value discount.
Note: The following fields are mutually exclusive: discount_absolute, discount_percentage. If a field in that set is populated, all other fields in the set will automatically be cleared.
280 281 282 283 |
# File 'proto_docs/google/cloud/channel/v1/offers.rb', line 280 class DiscountComponent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#discount_percentage ⇒ ::Float
Returns Discount percentage, represented as decimal. For example, a 20% discount will be represented as 0.2.
Note: The following fields are mutually exclusive: discount_percentage, discount_absolute. If a field in that set is populated, all other fields in the set will automatically be cleared.
280 281 282 283 |
# File 'proto_docs/google/cloud/channel/v1/offers.rb', line 280 class DiscountComponent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#discount_type ⇒ ::Google::Cloud::Channel::V1::DiscountType
Returns Type of the discount.
280 281 282 283 |
# File 'proto_docs/google/cloud/channel/v1/offers.rb', line 280 class DiscountComponent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |